day2

package
v0.0.0-...-fe6f56b Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 4, 2024 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Report

type Report struct {
	// contains filtered or unexported fields
}

func ReadInput

func ReadInput(filepath string) ([]Report, error)

ReadInput reads the input file and returns a slice of Reports. Each line in the input file represents a Report with space-separated integers.

Jump to